# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.shortcuts import render,redirect

from django.contrib.auth.backends import ModelBackend
from django.contrib.auth import authenticate, login, logout
#from django.contrib.auth.views import logout
from django.contrib import messages
from django.core.checks.messages import Error

from .forms import ConnexionForm, Bibtex2halForm, BibtexXmlForm, Csv2halForm, VerifHalConfForm, Bibformat2halForm ,\
    TextXmlForm, ModifTextForm,TextFromRG, Text2halForm

from haltools.settings import MEDIA_ROOT

from .scripts_bibtex import script_bibtex_2_hal
#from .scripts_text import script_text_2_hal
from .scripts_csv import script_csv_2_hal
from .scriptupdatehalranking import script_verify_hal_ranking #, script_verif_hal_ranking
from  .create_xml2hal import sendselect_2hal

from slugify import slugify
from datetime import datetime

import random
import string
#import httplib
#import xml.dom.minidom
import csv
import re

##################################################################################################################################
## SIMPLE VIEWS  #################################################################################################################
##################################################################################################################################

# return index
def index(request):
    print("test")
    return render(request, 'hal/index.html')
    
# allows connection through table User in database haltools
def connexion(request):
    reponse = ""
    form = ConnexionForm(request.POST or None)
    if form.is_valid():
        username = form.cleaned_data['username']
        password = form.cleaned_data['password']
        #print ('username :', username)
        authmodel = ModelBackend() #authentification backend django
        
        user = authenticate(request, username=username, password=password)
        if user is not None:
            login(request, user)
        else:
            reponse = ('Erreur d authentification')
                    
    return render(request, 'hal/connexion.html', locals())
    
    
# disconnect user
def deconnexion(request):
    logout(request)
    return render(request, 'hal/connexion.html', locals())

# return blog
def article_blog(request):
    return render(request, 'hal/blog.html', locals())

# return aide
def aide(request):
    return render(request, 'hal/aide.html', locals())

# Class used to describe a publication
class PubliDescribe():
    """
        Class used to re-create a list of all the publi 
    """
    def __init__(self):
        self.num = ""
        self.authors =""
        self.title = ""
        self.conf = ""
        self.page = ""
        self.vol = ""
        self.date = ""
        self.type = ""
        self.todo = ""
        self.ville = "" 
        self.pays = ""
        self.acr = ""
        self.doi = ""
        self.editor = ""
        self.lang = ""


class PubliChange():
    """
        Class used to re-create a list of all the publi 
    """
    def __init__(self):
        self.type = ""
        self.title = ""
        self.uri = ""
        self.date = ""
        self.change = ""
        self.conf = ""
        self.conf2 = ""
        self.owner = ""

##################################################################################################################################
## BIBTEX2HAL  ######################################################################################################################
##################################################################################################################################
      
def bibtex2hal(request):
    '''
        treats a bibtex file and some variables
        give a table of data (parsed bibtex file) and results of HAL depot
    '''   
    print("method views.bibtex2hal")
    reponse = ""
    csvfile = ""
    form = Bibtex2halForm(request.POST or None)
    
    if form.is_valid():
        name_user = form.cleaned_data['name_user']
        firstname_user = form.cleaned_data['firstname_user']
        labo_auth_final = form.cleaned_data['labo_auth_final']
        bibtex_file = form.cleaned_data['bibtex_file']       

        labo_auth_final = "struct-"+labo_auth_final


        print ("begin script")

        today = datetime.today()
        randomnumbers = ''.join(random.choices(string.digits, k=6))
        csvfile = "{0}_{1}-{2}_{3}".format(slugify(name_user),today.day, today.month,randomnumbers)

        msg_to_announce = "Attendre quelques minutes avant d'aller voir le résultat"
        reponse = script_bibtex_2_hal.delay(bibtex_file, name_user, firstname_user, labo_auth_final, csvfile)
        messages.add_message(request, messages.WARNING, msg_to_announce)
        
    return render(request, 'hal/bibtex2hal.html', locals())


def bibformat_2hal(request, csvfile):
    print("method views.bibformat_2hal")
    form = Bibformat2halForm(request.POST or None)
    try :

        with open('bibtex_csv_files/'+csvfile+'.csv', 'r', newline='') as csv_file :
            csvr = csv.reader(csv_file, delimiter =',')

            list_to_post = []
            for row in csvr :
                print(row)
                p = PubliDescribe() #PubliChange()

                p.num = row[0]
                p.authors =row[1]
                p.title = row[2]
                p.conf = row[3]
                p.page = row[4]
                p.vol = row[5]
                p.date = row[6]
                p.type = row[7]
                p.todo = row[8]
                p.ville = row[9] 
                p.pays = row[10]
                p.acr = row[11]
                p.doi = row[12]
                p.editor = row[13]
                p.lang = row[14]

                list_to_post.append(p)

        with open('bibtex_csv_files/result_'+csvfile+'.txt', 'r') as resultxt :
            result = resultxt.readlines()

        if form.is_valid():
            print("method views.bibformat_2hal FORM VALID")
            name_user = form.cleaned_data['name_user']
            login_user = form.cleaned_data['login_user']
            id_hal_user = form.cleaned_data['id_hal_user']
            mail_reponse = form.cleaned_data['mail_reponse']
            labo_auth_final = form.cleaned_data['labo_auth_final']
            domains = form.cleaned_data['domains']
            domains2 = form.cleaned_data['domains2']
            login_depot = form.cleaned_data['login_depot']
            passwd_depot = form.cleaned_data['passwd_depot']
            choice_depot = form.cleaned_data['choice_depot']

            list_publis_to_update = request.POST.getlist('chkbox')

            labo_auth_final = "struct-"+labo_auth_final
            listdomains = domains + domains2  
            for pub_upd in list_publis_to_update :
                print(pub_upd)
            
            msg_to_announce = "Après l'opération, les résultats seront envoyés à l'adresse : {0}".format(mail_reponse)
            messages.add_message(request, messages.WARNING, msg_to_announce)

            reponse = sendselect_2hal.delay(name_user,login_user,id_hal_user,mail_reponse,labo_auth_final,listdomains,login_depot,passwd_depot,choice_depot,list_publis_to_update,csvfile)
            

        return  render(request, 'hal/bibformat_2hal.html', locals())
    except Exception as e :
        print (e)
        return redirect('https://http.cat/425')


## A enlever
def validatepost2hal(request):
    print("method views.validatepost2hal")

    if request.method == 'POST' :
        print("method post")
        list_publis_to_update = request.POST.getlist('chkbox')
        #print(list_publis_to_update)
        for pub_upd in list_publis_to_update :
            print(pub_upd)

    return redirect('https://http.cat/425')

##################################################################################################################################
## bibtexXML  ######################################################################################################################
##################################################################################################################################

""" def bibtexxml(request):
    reponse = ""
    form = BibtexXmlForm(request.POST or None)

    if form.is_valid():
        # recup donnees
        bib_name_user = form.cleaned_data['bib_name_user']
        name_user = form.cleaned_data['name_user']
        firstname_user = form.cleaned_data['firstname_user']
        labo_auth_final = form.cleaned_data['labo_auth_final']
        id_hal_user = form.cleaned_data['id_hal_user']
        login_user = form.cleaned_data['login_user']
        domain1 = form.cleaned_data['domain1']
        domain2 = form.cleaned_data['domain2']
        domain3 = form.cleaned_data['domain3']
        domain4 = form.cleaned_data['domain4']
        domain5 = form.cleaned_data['domain5']

        choice_source = form.cleaned_data['choice_source']

        bibtex_file = form.cleaned_data['bibtex_file']
        login_depot = request.user
        passwd_depot = ""
        bool_depot_preprod = False
        bool_depot_prod = False
        single = True

        labo_auth_final = "struct-"+labo_auth_final

        #gestion domaines  domain1 obligatoire
        listdomains = []
        listdomains.append(domain1)
        if domain2 is not "" :
            listdomains.append(domain2)
        if domain3 is not "" :
            listdomains.append(domain3)
        if domain4 is not "" :
            listdomains.append(domain4)
        if domain5 is not "" :
            listdomains.append(domain5)

        reponse_to_post = script_bibtex_2_hal(bibtex_file, bib_name_user, name_user, firstname_user, labo_auth_final, id_hal_user, login_user, listdomains, login_depot, passwd_depot, bool_depot_preprod, bool_depot_prod, single, choice_source)

        #print (reponse_to_post)
    return render(request, 'hal/bibtexxml.html', locals()) """



##################################################################################################################################
## UPDATE_HAL  ######################################################################################################################
##################################################################################################################################
      
def verifhalconf_ranking(request):
    '''
        update HAL from Bitex DBLP -> change name conf
    '''   
    print("method views.verifhalconf_ranking")
    reponse = ""
    url_result = ""
    form = VerifHalConfForm(request.POST or None)

    csvfile = ""
    
    if form.is_valid():
        # get data from form

        name_user = form.cleaned_data['name_user']
        firstname_user = form.cleaned_data['firstname_user']
        id_hal_user = form.cleaned_data['id_hal_user']
        
        print ("begin script")

        today = datetime.today()
        randomnumbers = ''.join(random.choices(string.digits, k=6))
        csvfile = "{0}_{1}-{2}_{3}".format(slugify(name_user),today.day, today.month,randomnumbers)

        msg_to_announce = "Attendre quelques minutes avant d'aller voir le résultat"
        messages.add_message(request, messages.WARNING, msg_to_announce)
        reponse = script_verify_hal_ranking.delay(name_user, firstname_user, id_hal_user, csvfile)        
        
    return render(request, 'hal/verifhalconf_ranking.html', locals())


def verifhal_byuser(request, csvfile):
    print("method views.verifhal_byuser")
    try :

        with open('ranking_csv_files/'+csvfile+'.csv', 'r', newline='') as csv_file :
            csvr = csv.reader(csv_file, delimiter =',')

            list_to_post = []
            for row in csvr :
                print(row)
                p = PubliChange()
                p.type = row[0]
                p.title = row[1]
                p.uri = row[2]
                p.date = row[3]
                p.change = row[4]
                p.conf = row[5]
                p.conf2 = row[6]
                p.owner = row[7]
                
                list_to_post.append(p)

        return  render(request, 'hal/verifhal_byuser.html', locals())
    except Exception as e :
        print (e)
        return redirect('https://http.cat/425')



def valid_post_hal(request):
    print("method views.valid_update_hal")
    print(request)
    if request.method == 'POST' :
        print("method post")
        list_publis_to_update = request.POST.getlist('chkbox')
        #print(list_publis_to_update)
        for pub_upd in list_publis_to_update :
            print(pub_upd)
        
        #reponse = script_update_hal_ranking.delay(list_publis_to_update)
        
    return render(request,'hal/updatehal_byuser.html', locals() )



##################################################################################################################################
## CSV2HAL  #####################################################################################################################
##################################################################################################################################


def csv2hal(request):
    reponse = ""
    csvfile = ""
    form = Csv2halForm(request.POST or None)
    
    if form.is_valid():
        name_user = form.cleaned_data['name_user']
        firstname_user = form.cleaned_data['firstname_user']
        labo_auth_final = form.cleaned_data['labo_auth_final']
        csv_source = form.cleaned_data['csv_file']       

        labo_auth_final = "struct-"+labo_auth_final

        print ("begin script csv2hal")

        today = datetime.today()
        randomnumbers = ''.join(random.choices(string.digits, k=6))
        csvfile = "{0}_{1}-{2}_{3}".format(slugify(name_user),today.day, today.month,randomnumbers)

        msg_to_announce = "Attendre quelques minutes avant d'aller voir le résultat"
        reponse = script_csv_2_hal.delay( name_user, firstname_user, labo_auth_final, csv_source, csvfile)
        messages.add_message(request, messages.WARNING, msg_to_announce)

    """ reponse = ""
    form = Csv2halForm(request.POST or None)
    
    if form.is_valid():
        # recup donnees
        form_author = form.cleaned_data['form_author']
        name_user = form.cleaned_data['name_user']
        firstname_user = form.cleaned_data['firstname_user']
        labo_auth_final = form.cleaned_data['labo_auth_final']
        id_hal_user = form.cleaned_data['id_hal_user']
        login_user = form.cleaned_data['login_user']
        domain1 = form.cleaned_data['domain1']
        domain2 = form.cleaned_data['domain2']
        domain3 = form.cleaned_data['domain3']
        domain4 = form.cleaned_data['domain4']
        domain5 = form.cleaned_data['domain5']

        choice_source = form.cleaned_data['choice_source']
    
        login_depot = form.cleaned_data['login_depot']
        passwd_depot = form.cleaned_data['passwd_depot']
        #bool_depot_preprod = form.cleaned_data['bool_depot_preprod']
        #bool_depot_prod = form.cleaned_data['bool_depot_prod']
        choice_depot = form.cleaned_data['choice_depot']
        csv_file = form.cleaned_data['csv_file']

        bool_depot_preprod = False
        bool_depot_prod = False
        
        # recup du type de depot
        if choice_depot == 'PREPROD' :
            print ("Views.py depot preprod")
            bool_depot_preprod = True
        if choice_depot == 'PRODHAL' :
            print ("Views.py depot prod")
            bool_depot_prod = True

        
        labo_auth_final = "struct-"+labo_auth_final

        #gestion domaines  domain1 obligatoire
        listdomains = []
        listdomains.append(domain1)
        if domain2 is not "" :
            listdomains.append(domain2)
        if domain3 is not "" :
            listdomains.append(domain3)
        if domain4 is not "" :
            listdomains.append(domain4)
        if domain5 is not "" :
            listdomains.append(domain5)

        single = False

        #print ("begin script")
        print ("form_author "+form_author)
        reponse = script_csv_2_hal (csv_file, form_author, name_user, firstname_user, labo_auth_final, id_hal_user, login_user, listdomains, login_depot, passwd_depot, bool_depot_preprod, bool_depot_prod, single, choice_source)

        reponse_to_post = ""
        list_to_post = []
        for result in reponse :
            if result[0] == "RESULTATS" :
                reponse_to_post = reponse_to_post+"<br/><br/><b>"+result[1]+"</b><br/>"+result[2]
            else :
                p = PubliDescribe()
                p.num = result[0]
                p.authors = result[1]
                p.title = result[2]
                p.conf = result[3]
                p.page = result[4]
                p.vol = result[5]
                p.date = result[6]
                p.type = result[7]
                p.todo = result[8]
                p.ville = result[9]
                p.pays = result[10]
                p.acr = result[11]
                p.lang = result[12]
                
                list_to_post.append(p)
                #list_to_post.append((result[0],result[1],result[2],result[3],result[4],result[5],\
                #result[6],result[7],result[8],result[9],result[10],result[11],result[12],))
        #reponse=("reponse HAL") """
    return render(request, 'hal/csv2hal.html', locals())




##################################################################################################################################
## TEXT2HAL  #####################################################################################################################
##################################################################################################################################
"""
def text2hal(request):

    reponse = ""
    form = Text2halForm(request.POST or None)
    
    if form.is_valid():
        # recup donnees
        form_author = form.cleaned_data['form_author']
        name_user = form.cleaned_data['name_user']
        firstname_user = form.cleaned_data['firstname_user']
        labo_auth_final = form.cleaned_data['labo_auth_final']
        id_hal_user = form.cleaned_data['id_hal_user']
        login_user = form.cleaned_data['login_user']
        domain1 = form.cleaned_data['domain1']
        domain2 = form.cleaned_data['domain2']
        domain3 = form.cleaned_data['domain3']
        domain4 = form.cleaned_data['domain4']
        domain5 = form.cleaned_data['domain5']
    
        login_depot = form.cleaned_data['login_depot']
        passwd_depot = form.cleaned_data['passwd_depot']
        #bool_depot_preprod = form.cleaned_data['bool_depot_preprod']
        #bool_depot_prod = form.cleaned_data['bool_depot_prod']
        choice_depot = form.cleaned_data['choice_depot']
        text_file = form.cleaned_data['text_file']

        bool_depot_preprod = False
        bool_depot_prod = False
        
        # recup du type de depot
        if choice_depot == 'PREPROD' :
            print ("Views.py depot preprod")
            bool_depot_preprod = True
        if choice_depot == 'PRODHAL' :
            print ("Views.py depot prod")
            bool_depot_prod = True

        
        labo_auth_final = "struct-"+labo_auth_final

        #gestion domaines  domain1 obligatoire
        listdomains = []
        listdomains.append(domain1)
        if domain2 is not "" :
            listdomains.append(domain2)
        if domain3 is not "" :
            listdomains.append(domain3)
        if domain4 is not "" :
            listdomains.append(domain4)
        if domain5 is not "" :
            listdomains.append(domain5)

        single = False

        print ("begin script")
        reponse = script_text_2_hal(text_file, form_author, name_user, firstname_user, labo_auth_final, id_hal_user, login_user, listdomains, login_depot, passwd_depot, bool_depot_preprod, bool_depot_prod, single)
        
        reponse_to_post = ""
        list_to_post = []
        for result in reponse :
            if result[0] == "RESULTATS" :
                reponse_to_post = reponse_to_post+"<br/><br/><b>"+result[1]+"</b><br/>"+result[2]
            else :
                p = PubliDescribe()
                p.num = result[0]
                p.authors = result[1]
                p.title = result[2]
                p.conf = result[3]
                p.page = result[4]
                p.vol = result[5]
                p.date = result[6]
                p.type = result[7]
                p.todo = result[8]
                p.ville = result[9]
                p.pays = result[10]
                p.acr = result[11]
                p.lang = result[12]
                
                list_to_post.append(p)
                #list_to_post.append((result[0],result[1],result[2],result[3],result[4],result[5],\
                #result[6],result[7],result[8],result[9],result[10],result[11],result[12],))
        #reponse=("reponse HAL")
    return render(request, 'hal/text2hal.html', locals())
"""
##################################################################################################################################
## TEXTXML  ######################################################################################################################
##################################################################################################################################
"""
def textxml (request):
    reponse = ""
    form = TextXmlForm(request.POST or None)
    
    if form.is_valid():
        # recup donnees
        form_author = form.cleaned_data['form_author']
        name_user = form.cleaned_data['name_user']
        firstname_user = form.cleaned_data['firstname_user']
        labo_auth_final = form.cleaned_data['labo_auth_final']
        id_hal_user = form.cleaned_data['id_hal_user']
        login_user = form.cleaned_data['login_user']
        domain1 = form.cleaned_data['domain1']
        domain2 = form.cleaned_data['domain2']
        domain3 = form.cleaned_data['domain3']
        domain4 = form.cleaned_data['domain4']
        domain5 = form.cleaned_data['domain5']

        text_file = form.cleaned_data['text_file']
        login_depot = request.user
        passwd_depot = ""
        bool_depot_preprod = False
        bool_depot_prod = False
        single = True

        labo_auth_final = "struct-"+labo_auth_final
        
        #gestion domaines  domain1 obligatoire
        listdomains = []
        listdomains.append(domain1)
        if domain2 is not "" :
            listdomains.append(domain2)
        if domain3 is not "" :
            listdomains.append(domain3)
        if domain4 is not "" :
            listdomains.append(domain4)
        if domain5 is not "" :
            listdomains.append(domain5)

        single = True

        print ("begin script")
        reponse_to_post = script_text_2_hal(text_file, form_author, name_user, firstname_user, labo_auth_final, id_hal_user, login_user, listdomains, login_depot, passwd_depot, bool_depot_preprod, bool_depot_prod, single)

        #print ("REPONSE")
        #print (reponse_to_post)
    return render(request, 'hal/textxml.html', locals())

##################################################################################################################################
## TEXTMODIF  ####################################################################################################################
##################################################################################################################################

def textmodif(request):
    reponse = ""
    form = ModifTextForm(request.POST or None)
    if form.is_valid():
        # recup donnees
        delete_char = form.cleaned_data['delete_char']
        add_begin = form.cleaned_data['add_begin']
        clean_text = form.cleaned_data['clean_text']
        reverse_first_lastname = form.cleaned_data['reverse_first_lastname']
        get_volume = form.cleaned_data['get_volume']
        get_pages = form.cleaned_data['get_pages']
        transform_country = form.cleaned_data['transform_country']
        text_modif = form.cleaned_data['text_modif']

        reponse_to_post = text_modif

        # Action effectuee sur l'ensemble du texte
        if delete_char > 0 :
            result = ""
            list_publis = reponse_to_post.splitlines()
            for publi in list_publis :
                result = result + publi[delete_char:] + "\n"
            reponse_to_post = result

        # Action effectuee sur l'ensemble du texte
        if add_begin is not "" :
            result = ""
            cnt = 0
            list_publis = reponse_to_post.splitlines()
            for publi in list_publis :
                cnt+=1
                result = result + add_begin + str(cnt) + " - " + publi + "\n"
            reponse_to_post = result

        # Action effectuee sur l'ensemble du texte
        if clean_text == True :
            reponse_to_post = reponse_to_post.replace("« ","\"")
            reponse_to_post = reponse_to_post.replace(" »","\"")
            reponse_to_post = reponse_to_post.replace("«","\"")
            reponse_to_post = reponse_to_post.replace("»","\"")
            reponse_to_post = reponse_to_post.replace("‘","'")
            reponse_to_post = reponse_to_post.replace("’","'")
            reponse_to_post = reponse_to_post.replace("“","\"")
            reponse_to_post = reponse_to_post.replace("”","\"")
            reponse_to_post = reponse_to_post.replace("\"\"","\"")
            reponse_to_post = reponse_to_post.replace("  "," ")

        # Action effectuee ligne par ligne
        list_publis = reponse_to_post.splitlines()
        result = ""
        listauthors = ""
        for publi in list_publis :
            print ("**********")
            x = publi.find("-")
            numero = publi[0:x+1]
            publi = publi[x:]
            x = publi.find("\"")
            authors = publi[1:x]
            authors = authors.strip()
            listauthors = authors
            if reverse_first_lastname is True :
                listauthors = ""
                list_authors_mix = authors.split(",")
                
                # si champ vide, non pris en compte
                if list_authors_mix[-1].strip() == "" :
                    del list_authors_mix[-1]

                for auth in list_authors_mix :
                    auth = auth.strip()
                    newauth = auth.split(" ")
                    prenom = newauth[0]
                    nom = newauth[1]
                    print (nom, prenom)
                    listauthors = listauthors+nom + " "+prenom+","

            rest_publi = publi[x:]

            x = rest_publi.find("\"")
            title = rest_publi[:x]
            rest_publi = rest_publi[x:]

            x = rest_publi.find(",")
            conf = rest_publi[:x]
            rest_publi = rest_publi[x:]

            if get_volume == True :
                rest_publi = rest_publi.replace("Volume ","Vol. ")
                rest_publi = rest_publi.replace("volume ","Vol. ")
                rest_publi = rest_publi.replace("vol. ","Vol. ")

            if get_pages == True :
                
                rest_publi = rest_publi.replace("pages ","pp. ")

            if transform_country == True :
                print ("transform")
                list_pays = []
                with open('hal/countries.csv', 'rb') as csvfile: #open('/home/bastien/halenv/haltools/hal/countries.csv', 'rb') as csvfile:
                    delim = str(':')
                    quotech = str('|')
                    list_countries = csv.reader(csvfile, delimiter=delim, quotechar=quotech)
                    for row in list_countries:
                        list_pays.append((row[1],row[2],row[3]))

                match = False

                for pays in list_pays :
                    #rest_publi = rest_publi.decode("utf-8")
                    searched_country = pays[1].decode("utf-8")
                    country_index = rest_publi.find(searched_country)
                    if country_index > 0 :
                        country=rest_publi[country_index:]
                        print ("Country_text :"+country)
                        value_stop = re.findall(',',country)[0]  #([[:punct:]]|[[:space:]])
                        value_stop = country.find(value_stop)
                        if value_stop > 0 :
                            country=country[:value_stop]
                            print (country)
                            old_c = country
                            new_c = pays[0]
                            #print ("old ",old_c, " new ",new_c)
                            match = True

                if match == False :
                    for pays in list_pays :
                        #rest_publi = rest_publi.decode("utf-8")
                        searched_country = pays[2]#.decode("utf-8")
                        country_index = rest_publi.find(searched_country)
                        if country_index > 0 :
                            country=rest_publi[country_index:]
                            value_stop = re.findall(',',country)[0]
                            value_stop = country.find(value_stop)
                            if value_stop > 0 :
                                country=country[:value_stop]
                                print (country)
                                old_c = country
                                new_c = pays[0]
                                #print ("old ",old_c, " new ",new_c)
                                match = True

                if match == True :
                    rest_publi = rest_publi.replace(old_c, new_c)

                '''
                search_countries = rest_publi.split(",")
                for country in search_countries :
                    for pays in list_pays :
                        if country.strip() == pays[1] :
                            print ("************ MATCH *****************")
                            old_c = country
                            new_c = pays[0]
                            print ("old ",old_c, " new ",new_c)
                            match = True
                if match == True :
                    rest_publi = rest_publi.replace(old_c, new_c)
                '''
            # reconstruction texte
            print ("listauthors "+listauthors)
            result = result + numero +" "+ listauthors + title + conf + rest_publi + "\n"
        reponse_to_post = result

                        
    return render(request, 'hal/textmodif.html', locals())
    

##################################################################################################################################
## FORMAT_RG  ####################################################################################################################
##################################################################################################################################

def text_format(request):
    reponse = ""
    form = TextFromRG(request.POST or None) 
    result = ""
    if form.is_valid():
        # recup donnees
        choice_source = form.cleaned_data['choice_source']
        text_modif = form.cleaned_data['text_modif']

        reponse_to_post = text_modif

        list_publis = reponse_to_post.splitlines()

        result = ""

        # Format text for source Research_Gate
        if choice_source == "RG" :
            for publi in list_publis :
                print ("********************")
                #publi = publi[1:]
                #print (publi)
                x = publi.find(":")#.decode('utf-8')
                authors = publi[0:x]
                authors = authors.strip()
        
                rest_publi = publi[x+1:]
            
                x = rest_publi.find(".")
                title = rest_publi[1:x]
                rest_publi = rest_publi[x+1:]
        
                conf = ""
                year = ""
                vol = ""
                pp = ""
                # recherche de l'element mois + /  -> 04/ 11/  ...
                try : 
                    end_conf = re.findall('\s[0-1][0-9][\/]', rest_publi)[0]
                    x = rest_publi.find(end_conf)
                    if x > -1 :
                        conf = rest_publi[:x]
                        conf = conf.replace(";","")
                        conf = conf.strip()
                        rest_publi = rest_publi[x:]
                        print ("rest_publi 1 :"+rest_publi)
                        year = rest_publi[4:]
                        x = year.find(";")
                        # si ; apres annee --> article, sinon conf
        
                        if x > -1 :     # ARTICLE
                            year = year[:x]
                            year = year.replace(",","")
                            year = year.strip()
                            rest_publi = rest_publi[x+4:]
                            print ("rest_publi 2 :"+rest_publi)
        
                            vol = rest_publi
        
                            y = vol.find("DOI")
                            if y > -1 :
                                vol = vol[:y]
        
                            y = vol.find(":")
                            if y > -1 :
                                vol = vol[:y]
                                vol = vol.replace(";","")
                                vol = vol.strip()
                                rest_publi = rest_publi[y+1:] 
                                print ("rest_publi 3 :"+rest_publi)
                                pp = rest_publi
                                z = pp.find("DOI")
                                pp = pp[:z-1]
                                pp = pp.replace(".","")
                                pp = pp.replace(",","")
                                pp = pp.strip()
                                rest_publi = rest_publi[z:]

        
                                print ("rest_publi 4 :"+rest_publi)
        
                            elif y == -1 :
                                print ("--> --> --> NO PAGES rest_publi 3 :"+rest_publi)
                                y = vol.find(".")
                                vol = vol[:y]
                                vol = vol.replace(";","")
                                vol = vol.replace(",","")
                                rest_publi = rest_publi[y+2:] 

                            rest_publi = rest_publi.replace("DOI:","doi:")    
        
                            print ("year "+year + " vol "+vol+ "  pages "+pp + "  rest_pub "+ rest_publi)
        
                        elif x == -1 :     # CONF
                            end_year = re.findall('\D', year)[0]
                            x = year.find(end_year)
                            
                            year = year[:x]
                            print ("YEAR "+year)
        
                    #print ("rest_publi "+rest_publi)
                except IndexError :
                    print ("IndexError "+title)
        
                #x = publi.find("-")#.decode('utf-8')
                #numero = publi[0:x]
                end_string_vol_pages = ""
                if vol is not "" :
                    end_string_vol_pages = end_string_vol_pages+", Vol. "+vol
                if pp is not "" :
                    end_string_vol_pages = end_string_vol_pages+", pp. "+pp
                #print ("end_string_vol_pages "+end_string_vol_pages)
                result = result+authors+","+"\""+title+"\","+conf+", "+year+end_string_vol_pages+", "+rest_publi+"\n"# +rest_publi
    
    
    print (result)
    reponse_to_post = result
           
    return render(request, 'hal/text_format.html', locals())


"""